@@ -91,13 +91,21 @@ class CodeStarNotificationsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client/#close)
+        """
+
     def create_notification_rule(
         self,
         *,
         Name: str,
         EventTypeIds: Sequence[str],
         Resource: str,
-        Targets: Sequence["TargetTypeDef"],
+        Targets: Sequence[TargetTypeDef],
         DetailType: DetailTypeType,
         ClientRequestToken: str = ...,
         Tags: Mapping[str, str] = ...,
@@ -153,7 +161,7 @@ class CodeStarNotificationsClient(BaseClient):
     def list_event_types(
         self,
         *,
-        Filters: Sequence["ListEventTypesFilterTypeDef"] = ...,
+        Filters: Sequence[ListEventTypesFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListEventTypesResultTypeDef:
@@ -168,12 +176,12 @@ class CodeStarNotificationsClient(BaseClient):
     def list_notification_rules(
         self,
         *,
-        Filters: Sequence["ListNotificationRulesFilterTypeDef"] = ...,
+        Filters: Sequence[ListNotificationRulesFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListNotificationRulesResultTypeDef:
         """
-        Returns a list of the notification rules for an AWS account.
+        Returns a list of the notification rules for an Amazon Web Services account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_notification_rules)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client/#list_notification_rules)
@@ -190,24 +198,25 @@ class CodeStarNotificationsClient(BaseClient):
     def list_targets(
         self,
         *,
-        Filters: Sequence["ListTargetsFilterTypeDef"] = ...,
+        Filters: Sequence[ListTargetsFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListTargetsResultTypeDef:
         """
-        Returns a list of the notification rule targets for an AWS account.
+        Returns a list of the notification rule targets for an Amazon Web Services
+        account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_targets)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client/#list_targets)
         """
 
     def subscribe(
-        self, *, Arn: str, Target: "TargetTypeDef", ClientRequestToken: str = ...
+        self, *, Arn: str, Target: TargetTypeDef, ClientRequestToken: str = ...
     ) -> SubscribeResultTypeDef:
         """
-        Creates an association between a notification rule and an SNS topic so that the
-        associated target can receive notifications when the events described in the
-        rule are triggered.
+        Creates an association between a notification rule and an Chatbot topic or
+        Chatbot client so that the associated target can receive notifications when the
+        events described in the rule are triggered.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Client.subscribe)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client/#subscribe)
@@ -223,9 +232,9 @@ class CodeStarNotificationsClient(BaseClient):
 
     def unsubscribe(self, *, Arn: str, TargetAddress: str) -> UnsubscribeResultTypeDef:
         """
-        Removes an association between a notification rule and an Amazon SNS topic so
-        that subscribers to that topic stop receiving notifications when the events
-        described in the rule are triggered.
+        Removes an association between a notification rule and an Chatbot topic so that
+        subscribers to that topic stop receiving notifications when the events described
+        in the rule are triggered.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Client.unsubscribe)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client/#unsubscribe)
@@ -247,7 +256,7 @@ class CodeStarNotificationsClient(BaseClient):
         Name: str = ...,
         Status: NotificationRuleStatusType = ...,
         EventTypeIds: Sequence[str] = ...,
-        Targets: Sequence["TargetTypeDef"] = ...,
+        Targets: Sequence[TargetTypeDef] = ...,
         DetailType: DetailTypeType = ...
     ) -> Dict[str, Any]:
         """
