@@ -25,8 +25,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListEventTypesFilterTypeDef,
@@ -51,7 +50,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListEventTypesPaginator(Boto3Paginator):
+class ListEventTypesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators/#listeventtypespaginator)
@@ -60,8 +59,8 @@ class ListEventTypesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["ListEventTypesFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[ListEventTypesFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEventTypesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
@@ -69,7 +68,7 @@ class ListEventTypesPaginator(Boto3Paginator):
         """
 
 
-class ListNotificationRulesPaginator(Boto3Paginator):
+class ListNotificationRulesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators/#listnotificationrulespaginator)
@@ -78,8 +77,8 @@ class ListNotificationRulesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["ListNotificationRulesFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[ListNotificationRulesFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListNotificationRulesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
@@ -87,7 +86,7 @@ class ListNotificationRulesPaginator(Boto3Paginator):
         """
 
 
-class ListTargetsPaginator(Boto3Paginator):
+class ListTargetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators/#listtargetspaginator)
@@ -96,8 +95,8 @@ class ListTargetsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["ListTargetsFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[ListTargetsFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTargetsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
